diff --git a/livesupport/etc/debian/livesupport-station.postrm b/livesupport/etc/debian/livesupport-station.postrm
index 1ff5f56e8..b89b2c766 100644
--- a/livesupport/etc/debian/livesupport-station.postrm
+++ b/livesupport/etc/debian/livesupport-station.postrm
@@ -1,5 +1,5 @@
#! /bin/sh
-# postrm script for livesupport
+# postrm script for campcaster
#
# see: dh_installdeb(1)
@@ -17,14 +17,14 @@ set -e
# for details, see http://www.debian.org/doc/debian-policy/ or
# the debian-policy package
-installdir=/opt/livesupport
+installdir=/opt/campcaster
apache_docroot=/var/www
postgres_user=postgres
ls_dbserver=localhost
-ls_database=LiveSupport
-ls_dbuser=livesupport
+ls_database=Campcaster
+ls_dbuser=campcaster
#-------------------------------------------------------------------------------
@@ -47,18 +47,18 @@ check_exe() {
case "$1" in
remove|upgrade|failed-upgrade|abort-install|abort-upgrade)
# remove the init script
- rm -f /etc/init.d/livesupport-station
- update-rc.d livesupport-station remove
+ rm -f /etc/init.d/campcaster-station
+ update-rc.d campcaster-station remove
- # remove the symlink to the livesupport web pages
- rm -f $apache_docroot/livesupport
+ # remove the symlink to the campcaster web pages
+ rm -f $apache_docroot/campcaster
# restore the old pg_hba.conf file
if [ -f /etc/postgresql/pg_hba.conf ] \
- && [ -f /etc/postgresql/pg_hba.conf.before-livesupport ] ; then
+ && [ -f /etc/postgresql/pg_hba.conf.before-campcaster ] ; then
mv -f /etc/postgresql/pg_hba.conf \
- /etc/postgresql/pg_hba.conf.livesupport ;
- mv -f /etc/postgresql/pg_hba.conf.before-livesupport \
+ /etc/postgresql/pg_hba.conf.campcaster ;
+ mv -f /etc/postgresql/pg_hba.conf.before-campcaster \
/etc/postgresql/pg_hba.conf ;
fi
;;
@@ -75,14 +75,14 @@ case "$1" in
rm -rf $installdir/etc/scheduler.xml
rm -rf $installdir/etc/gst-registry.xml
rm -rf $installdir/etc/pear.conf
- rm -rf $installdir/var/LiveSupport/htmlUI/var/html/img/*
- rm -rf $installdir/var/LiveSupport/htmlUI/var/templates_c/*
- rm -rf $installdir/var/LiveSupport/storageServer/var/stor/*
- rm -rf $installdir/var/LiveSupport/storageServer/var/access/*
- rm -rf $installdir/var/LiveSupport/storageServer/var/trans/*
- rm -rf $installdir/var/LiveSupport/archiveServer/var/stor/*
- rm -rf $installdir/var/LiveSupport/archiveServer/var/access/*
- rm -rf $installdir/var/LiveSupport/archiveServer/var/trans/*
+ rm -rf $installdir/var/Campcaster/htmlUI/var/html/img/*
+ rm -rf $installdir/var/Campcaster/htmlUI/var/templates_c/*
+ rm -rf $installdir/var/Campcaster/storageServer/var/stor/*
+ rm -rf $installdir/var/Campcaster/storageServer/var/access/*
+ rm -rf $installdir/var/Campcaster/storageServer/var/trans/*
+ rm -rf $installdir/var/Campcaster/archiveServer/var/stor/*
+ rm -rf $installdir/var/Campcaster/archiveServer/var/access/*
+ rm -rf $installdir/var/Campcaster/archiveServer/var/trans/*
echo "Removing ODBC data source and driver...";
@@ -90,7 +90,7 @@ case "$1" in
# kill active connections to LiveSuport database
/etc/init.d/postgresql restart
- echo "Removing LiveSupport ODBC data source...";
+ echo "Removing Campcaster ODBC data source...";
odbcinst -u -s -l -n $ls_database || exit 1;
echo "De-registering ODBC PostgreSQL driver...";
diff --git a/livesupport/src/modules/authentication/etc/doxygen.config b/livesupport/src/modules/authentication/etc/doxygen.config
index 5c6e997b4..bb7b13cec 100644
--- a/livesupport/src/modules/authentication/etc/doxygen.config
+++ b/livesupport/src/modules/authentication/etc/doxygen.config
@@ -44,7 +44,7 @@
# The PROJECT_NAME tag is a single word (or a sequence of words surrounded
# by quotes) that should identify the project.
-PROJECT_NAME = LiveSupport
+PROJECT_NAME = Campcaster
# The PROJECT_NUMBER tag can be used to enter a project or revision number.
# This could be handy for archiving the generated documentation or
diff --git a/livesupport/src/modules/authentication/etc/webAuthentication.xml b/livesupport/src/modules/authentication/etc/webAuthentication.xml
index 7593d0d28..c10f709e7 100644
--- a/livesupport/src/modules/authentication/etc/webAuthentication.xml
+++ b/livesupport/src/modules/authentication/etc/webAuthentication.xml
@@ -10,5 +10,5 @@
]>
+ path="/campcasterStorageServer/xmlrpc/xrLocStor.php" />
diff --git a/livesupport/src/modules/core/etc/audioClip.xml b/livesupport/src/modules/core/etc/audioClip.xml
index 84fccd1d8..7bb083628 100644
--- a/livesupport/src/modules/core/etc/audioClip.xml
+++ b/livesupport/src/modules/core/etc/audioClip.xml
@@ -2,8 +2,8 @@
- LiveSupport unit test results
+ Campcaster unit test results
Preface
This document is part of the
-LiveSupport
+Campcaster
project, Copyright © 2004 Media
Development Loan Fund, under the GNU
GPL.
@@ -18,7 +18,7 @@ Development Loan Fund, under the GNU
This is an automatically generated document.
Scope
This document contains the generated unit test results for the
-LiveSupport project.
+Campcaster project.
Summary
diff --git a/livesupport/src/modules/core/include/LiveSupport/Core/BaseTestMethod.h b/livesupport/src/modules/core/include/LiveSupport/Core/BaseTestMethod.h
index 078f46203..48f252c39 100644
--- a/livesupport/src/modules/core/include/LiveSupport/Core/BaseTestMethod.h
+++ b/livesupport/src/modules/core/include/LiveSupport/Core/BaseTestMethod.h
@@ -61,7 +61,7 @@ namespace Core {
* A base class for the test methods.
* Subclass this class for the methods that use configuration files.
* This class gives helpers to access the configuration files
- * from various locations (~/.livesupport, ./etc)
+ * from various locations (~/.campcaster, ./etc)
*
* @author $Author$
* @version $Revision$
diff --git a/livesupport/src/modules/db/etc/connectionManagerFactory.xml b/livesupport/src/modules/db/etc/connectionManagerFactory.xml
index 0eb143638..9e7c74905 100644
--- a/livesupport/src/modules/db/etc/connectionManagerFactory.xml
+++ b/livesupport/src/modules/db/etc/connectionManagerFactory.xml
@@ -9,7 +9,7 @@
]>
-
diff --git a/livesupport/src/modules/db/etc/doxygen.config b/livesupport/src/modules/db/etc/doxygen.config
index 5198ec68c..78bf0f7e6 100644
--- a/livesupport/src/modules/db/etc/doxygen.config
+++ b/livesupport/src/modules/db/etc/doxygen.config
@@ -44,7 +44,7 @@
# The PROJECT_NAME tag is a single word (or a sequence of words surrounded
# by quotes) that should identify the project.
-PROJECT_NAME = LiveSupport
+PROJECT_NAME = Campcaster
# The PROJECT_NUMBER tag can be used to enter a project or revision number.
# This could be handy for archiving the generated documentation or
diff --git a/livesupport/src/modules/db/etc/simpleConnectionManager.xml b/livesupport/src/modules/db/etc/simpleConnectionManager.xml
index 23d414437..aa25afaab 100644
--- a/livesupport/src/modules/db/etc/simpleConnectionManager.xml
+++ b/livesupport/src/modules/db/etc/simpleConnectionManager.xml
@@ -6,7 +6,7 @@
]>
-
diff --git a/livesupport/src/modules/db/etc/testResultToHtml.xsl b/livesupport/src/modules/db/etc/testResultToHtml.xsl
index d2165c2a4..b70f32d45 100644
--- a/livesupport/src/modules/db/etc/testResultToHtml.xsl
+++ b/livesupport/src/modules/db/etc/testResultToHtml.xsl
@@ -5,12 +5,12 @@
- LiveSupport unit test results
+ Campcaster unit test results
Preface
This document is part of the
-LiveSupport
+Campcaster
project, Copyright © 2004 Media
Development Loan Fund, under the GNU
GPL.
@@ -18,7 +18,7 @@ Development Loan Fund, under the GNU
This is an automatically generated document.
Scope
This document contains the generated unit test results for the
-LiveSupport project.
+Campcaster project.
Summary
diff --git a/livesupport/src/modules/eventScheduler/etc/doxygen.config b/livesupport/src/modules/eventScheduler/etc/doxygen.config
index 5c6e997b4..bb7b13cec 100644
--- a/livesupport/src/modules/eventScheduler/etc/doxygen.config
+++ b/livesupport/src/modules/eventScheduler/etc/doxygen.config
@@ -44,7 +44,7 @@
# The PROJECT_NAME tag is a single word (or a sequence of words surrounded
# by quotes) that should identify the project.
-PROJECT_NAME = LiveSupport
+PROJECT_NAME = Campcaster
# The PROJECT_NUMBER tag can be used to enter a project or revision number.
# This could be handy for archiving the generated documentation or
diff --git a/livesupport/src/modules/eventScheduler/etc/testResultToHtml.xsl b/livesupport/src/modules/eventScheduler/etc/testResultToHtml.xsl
index d2165c2a4..b70f32d45 100644
--- a/livesupport/src/modules/eventScheduler/etc/testResultToHtml.xsl
+++ b/livesupport/src/modules/eventScheduler/etc/testResultToHtml.xsl
@@ -5,12 +5,12 @@
- LiveSupport unit test results
+ Campcaster unit test results
Preface
This document is part of the
-LiveSupport
+Campcaster
project, Copyright © 2004 Media
Development Loan Fund, under the GNU
GPL.
@@ -18,7 +18,7 @@ Development Loan Fund, under the GNU
This is an automatically generated document.
Scope
This document contains the generated unit test results for the
-LiveSupport project.
+Campcaster project.
Summary
diff --git a/livesupport/src/modules/gstreamerElements/etc/doxygen.config b/livesupport/src/modules/gstreamerElements/etc/doxygen.config
index df1ed0300..6788ad8b3 100644
--- a/livesupport/src/modules/gstreamerElements/etc/doxygen.config
+++ b/livesupport/src/modules/gstreamerElements/etc/doxygen.config
@@ -44,7 +44,7 @@
# The PROJECT_NAME tag is a single word (or a sequence of words surrounded
# by quotes) that should identify the project.
-PROJECT_NAME = LiveSupport
+PROJECT_NAME = Campcaster
# The PROJECT_NUMBER tag can be used to enter a project or revision number.
# This could be handy for archiving the generated documentation or
diff --git a/livesupport/src/modules/playlistExecutor/etc/doxygen.config b/livesupport/src/modules/playlistExecutor/etc/doxygen.config
index 5c6e997b4..bb7b13cec 100644
--- a/livesupport/src/modules/playlistExecutor/etc/doxygen.config
+++ b/livesupport/src/modules/playlistExecutor/etc/doxygen.config
@@ -44,7 +44,7 @@
# The PROJECT_NAME tag is a single word (or a sequence of words surrounded
# by quotes) that should identify the project.
-PROJECT_NAME = LiveSupport
+PROJECT_NAME = Campcaster
# The PROJECT_NUMBER tag can be used to enter a project or revision number.
# This could be handy for archiving the generated documentation or
diff --git a/livesupport/src/modules/playlistExecutor/etc/testResultToHtml.xsl b/livesupport/src/modules/playlistExecutor/etc/testResultToHtml.xsl
index d2165c2a4..b70f32d45 100644
--- a/livesupport/src/modules/playlistExecutor/etc/testResultToHtml.xsl
+++ b/livesupport/src/modules/playlistExecutor/etc/testResultToHtml.xsl
@@ -5,12 +5,12 @@
- LiveSupport unit test results
+ Campcaster unit test results
Preface
This document is part of the
-LiveSupport
+Campcaster
project, Copyright © 2004 Media
Development Loan Fund, under the GNU
GPL.
@@ -18,7 +18,7 @@ Development Loan Fund, under the GNU
This is an automatically generated document.
Scope
This document contains the generated unit test results for the
-LiveSupport project.
+Campcaster project.
Summary
diff --git a/livesupport/src/modules/schedulerClient/etc/doxygen.config b/livesupport/src/modules/schedulerClient/etc/doxygen.config
index 5c6e997b4..bb7b13cec 100644
--- a/livesupport/src/modules/schedulerClient/etc/doxygen.config
+++ b/livesupport/src/modules/schedulerClient/etc/doxygen.config
@@ -44,7 +44,7 @@
# The PROJECT_NAME tag is a single word (or a sequence of words surrounded
# by quotes) that should identify the project.
-PROJECT_NAME = LiveSupport
+PROJECT_NAME = Campcaster
# The PROJECT_NUMBER tag can be used to enter a project or revision number.
# This could be handy for archiving the generated documentation or
diff --git a/livesupport/src/modules/storageClient/etc/doxygen.config b/livesupport/src/modules/storageClient/etc/doxygen.config
index 5c6e997b4..bb7b13cec 100644
--- a/livesupport/src/modules/storageClient/etc/doxygen.config
+++ b/livesupport/src/modules/storageClient/etc/doxygen.config
@@ -44,7 +44,7 @@
# The PROJECT_NAME tag is a single word (or a sequence of words surrounded
# by quotes) that should identify the project.
-PROJECT_NAME = LiveSupport
+PROJECT_NAME = Campcaster
# The PROJECT_NUMBER tag can be used to enter a project or revision number.
# This could be handy for archiving the generated documentation or
diff --git a/livesupport/src/modules/storageClient/etc/testResultToHtml.xsl b/livesupport/src/modules/storageClient/etc/testResultToHtml.xsl
index d2165c2a4..b70f32d45 100644
--- a/livesupport/src/modules/storageClient/etc/testResultToHtml.xsl
+++ b/livesupport/src/modules/storageClient/etc/testResultToHtml.xsl
@@ -5,12 +5,12 @@
- LiveSupport unit test results
+ Campcaster unit test results
Preface
This document is part of the
-LiveSupport
+Campcaster
project, Copyright © 2004 Media
Development Loan Fund, under the GNU
GPL.
@@ -18,7 +18,7 @@ Development Loan Fund, under the GNU
This is an automatically generated document.
Scope
This document contains the generated unit test results for the
-LiveSupport project.
+Campcaster project.
Summary
diff --git a/livesupport/src/modules/storageClient/etc/webAuthenticationClient.xml b/livesupport/src/modules/storageClient/etc/webAuthenticationClient.xml
index f13840213..a63a04718 100644
--- a/livesupport/src/modules/storageClient/etc/webAuthenticationClient.xml
+++ b/livesupport/src/modules/storageClient/etc/webAuthenticationClient.xml
@@ -14,6 +14,6 @@
+ path="/campcasterStorageServer/xmlrpc/xrLocStor.php" />
diff --git a/livesupport/src/modules/storageClient/etc/webStorage.xml b/livesupport/src/modules/storageClient/etc/webStorage.xml
index 5471c5f25..70384a868 100644
--- a/livesupport/src/modules/storageClient/etc/webStorage.xml
+++ b/livesupport/src/modules/storageClient/etc/webStorage.xml
@@ -12,5 +12,5 @@
]>
+ path="/campcasterStorageServer/xmlrpc/xrLocStor.php" />
diff --git a/livesupport/src/modules/widgets/etc/doxygen.config b/livesupport/src/modules/widgets/etc/doxygen.config
index 5198ec68c..78bf0f7e6 100644
--- a/livesupport/src/modules/widgets/etc/doxygen.config
+++ b/livesupport/src/modules/widgets/etc/doxygen.config
@@ -44,7 +44,7 @@
# The PROJECT_NAME tag is a single word (or a sequence of words surrounded
# by quotes) that should identify the project.
-PROJECT_NAME = LiveSupport
+PROJECT_NAME = Campcaster
# The PROJECT_NUMBER tag can be used to enter a project or revision number.
# This could be handy for archiving the generated documentation or
diff --git a/livesupport/src/products/gLiveSupport/bin/gLiveSupport.sh b/livesupport/src/products/gLiveSupport/bin/gLiveSupport.sh
index 08636c12a..b292eb6d5 100755
--- a/livesupport/src/products/gLiveSupport/bin/gLiveSupport.sh
+++ b/livesupport/src/products/gLiveSupport/bin/gLiveSupport.sh
@@ -27,7 +27,7 @@
#-------------------------------------------------------------------------------
#-------------------------------------------------------------------------------
-# Invoke script for the LiveSupport gui.
+# Invoke script for Campcaster Studio.
#-------------------------------------------------------------------------------
@@ -48,18 +48,18 @@ tmpdir=$basedir/tmp
gstreamer_dir=`find $libdir -type d -name "gstreamer-*"`
export LD_LIBRARY_PATH=$libdir:$LD_LIBRARY_PATH
-gLiveSupport_exe=$bindir/gLiveSupport
+studio_exe=$bindir/campcaster-studio
-if [ -f ~/.livesupport/gLiveSupport.xml ]; then
- config_file=~/.livesupport/gLiveSupport.xml
-elif [ -f $etcdir/gLiveSupport.xml ]; then
- config_file=$etcdir/gLiveSupport.xml
+if [ -f ~/.campcaster/campcaster-studio.xml ]; then
+ config_file=~/.campcaster/campcaster-studio.xml
+elif [ -f $etcdir/campcaster-studio.xml ]; then
+ config_file=$etcdir/campcaster-studio.xml
else
echo "Can't find configuration file.";
fi
-$gLiveSupport_exe --version
+$studio_exe --version
echo "using configuration file: $config_file";
-$gLiveSupport_exe -c $config_file
+$studio_exe -c $config_file
diff --git a/livesupport/src/products/gLiveSupport/bin/gLiveSupport_devenv.sh b/livesupport/src/products/gLiveSupport/bin/gLiveSupport_devenv.sh
index 992417e55..f57e60fab 100755
--- a/livesupport/src/products/gLiveSupport/bin/gLiveSupport_devenv.sh
+++ b/livesupport/src/products/gLiveSupport/bin/gLiveSupport_devenv.sh
@@ -27,8 +27,8 @@
#-------------------------------------------------------------------------------
#-------------------------------------------------------------------------------
-# System V runlevel style invoke script for the LiveSupport Scheduler
-# This script is only used in the LiveSupport development environment
+# Invoke script for Campcaster Studio.
+# This script is only used in the Campcaster development environment.
#-------------------------------------------------------------------------------
@@ -50,22 +50,22 @@ usrdir=`cd $basedir/../../../usr; pwd;`
#-------------------------------------------------------------------------------
export LD_LIBRARY_PATH=$usrdir/lib:$LD_LIBRARY_PATH
-if [ -x $tmpdir/gLiveSupport ]; then
- gLiveSupport_exe=$tmpdir/gLiveSupport
+if [ -x $tmpdir/campcaster-studio ]; then
+ studio_exe=$tmpdir/campcaster-studio
else
echo "Can't find scheduler executable.";
fi
-if [ -f ~/.livesupport/gLiveSupport.xml ]; then
- config_file=~/.livesupport/gLiveSupport.xml
-elif [ -f $etcdir/gLiveSupport.xml ]; then
- config_file=$etcdir/gLiveSupport.xml
+if [ -f ~/.campcaster/campcaster-studio.xml ]; then
+ config_file=~/.campcaster/campcaster-studio.xml
+elif [ -f $etcdir/campcaster-studio.xml ]; then
+ config_file=$etcdir/campcaster-studio.xml
else
echo "Can't find configuration file.";
fi
-mode=$1
+$studio_exe --version
echo "using configuration file: $config_file";
-$gLiveSupport_exe -c $config_file
+$studio_exe -c $config_file
diff --git a/livesupport/src/products/gLiveSupport/etc/Makefile.in b/livesupport/src/products/gLiveSupport/etc/Makefile.in
index e28dbc275..6a0dce722 100644
--- a/livesupport/src/products/gLiveSupport/etc/Makefile.in
+++ b/livesupport/src/products/gLiveSupport/etc/Makefile.in
@@ -78,7 +78,7 @@ DB_PASSWORD = @DB_PASSWORD@
AUDIO_OUT = "@AUDIO_OUT@"
AUDIO_CUE = "@AUDIO_CUE@"
-PHP_URL_PREFIX=livesupport
+PHP_URL_PREFIX=campcaster
ALIB_XML_RPC_PREFIX=xmlrpc/xrLocStor.php
SCHEDULER_XML_RPC_PREFIX=RC2
SCHEDULER_DAEMON_COMMAND="sudo ${USR_BIN_DIR}/scheduler.sh"
@@ -191,9 +191,9 @@ TEST_RESULTS = ${DOC_DIR}/testResults.xml
# the text result XSLT has to be relative to the test result file, e.g. TMP_DIR
TEST_XSLT = ../etc/testResultToHtml.xsl
-G_LIVESUPPORT_EXE = ${TMP_DIR}/gLiveSupport
-G_LIVESUPPORT_SH = ${BIN_DIR}/gLiveSupport_devenv.sh
-G_LIVESUPPORT_CFG = ${ETC_DIR}/gLiveSupport.xml
+G_LIVESUPPORT_EXE = ${TMP_DIR}/campcaster-studio
+G_LIVESUPPORT_SH = ${BIN_DIR}/campcaster-studio_devenv.sh
+G_LIVESUPPORT_CFG = ${ETC_DIR}/campcaster-studio.xml
TEST_RUNNER = ${TMP_DIR}/testRunner
DOXYGEN_CONFIG = ${ETC_DIR}/doxygen.config
@@ -351,7 +351,7 @@ install: all
${MKDIR} ${USR_ETC_DIR}
${MKDIR} ${USR_VAR_DIR}/LiveSupport
${CP} ${TMP_DIR}/*.res ${USR_VAR_DIR}/LiveSupport
- ${CP} ${VAR_DIR}/livesupport.png \
+ ${CP} ${VAR_DIR}/campcaster.png \
${VAR_DIR}/stationLogo.png \
${VAR_DIR}/icon*.png \
${VAR_DIR}/testAudio.ogg \
diff --git a/livesupport/src/products/gLiveSupport/etc/authenticationClient.xml b/livesupport/src/products/gLiveSupport/etc/authenticationClient.xml
index f13840213..a63a04718 100644
--- a/livesupport/src/products/gLiveSupport/etc/authenticationClient.xml
+++ b/livesupport/src/products/gLiveSupport/etc/authenticationClient.xml
@@ -14,6 +14,6 @@
+ path="/campcasterStorageServer/xmlrpc/xrLocStor.php" />
diff --git a/livesupport/src/products/gLiveSupport/etc/campcaster-studio.xml b/livesupport/src/products/gLiveSupport/etc/campcaster-studio.xml
index ccb6a799f..09bb1b4e6 100644
--- a/livesupport/src/products/gLiveSupport/etc/campcaster-studio.xml
+++ b/livesupport/src/products/gLiveSupport/etc/campcaster-studio.xml
@@ -119,7 +119,7 @@
]>
-
@@ -138,14 +138,14 @@
+ path="/campcasterStorageServer/xmlrpc/xrLocStor.php" />
+ path="/campcasterStorageServer/xmlrpc/xrLocStor.php" />
diff --git a/livesupport/src/products/gLiveSupport/etc/campcaster-studio.xml.template b/livesupport/src/products/gLiveSupport/etc/campcaster-studio.xml.template
index d30279fd5..b46ebfb60 100644
--- a/livesupport/src/products/gLiveSupport/etc/campcaster-studio.xml.template
+++ b/livesupport/src/products/gLiveSupport/etc/campcaster-studio.xml.template
@@ -119,7 +119,7 @@
]>
-
@@ -133,7 +133,7 @@
-
+
@@ -143,7 +143,7 @@
-
+
@@ -171,16 +171,16 @@
-
+
-
-
-
-
+
+
+
+
-
+
-
diff --git a/livesupport/src/products/gLiveSupport/etc/configure.ac b/livesupport/src/products/gLiveSupport/etc/configure.ac
index 8f39d4e8e..efb68d830 100644
--- a/livesupport/src/products/gLiveSupport/etc/configure.ac
+++ b/livesupport/src/products/gLiveSupport/etc/configure.ac
@@ -32,7 +32,7 @@ dnl This is due to the fact that configure spreads a lot of trash around,
dnl like atom4te cache directories, config.* files, etc. into the directory
dnl it is being run from. We clearly don't want these in our base directory.
dnl-----------------------------------------------------------------------------
-AC_INIT(gLiveSupport, 1.1, bugs@campware.org)
+AC_INIT(Campcaster-Studio, 1.1, bugs@campware.org)
AC_PREREQ(2.59)
AC_COPYRIGHT([Copyright (c) 2004 Media Development Loan Fund under the GNU GPL])
AC_REVISION($Revision$)
@@ -187,14 +187,14 @@ AC_MSG_RESULT([using database server: ${DB_SERVER}])
dnl-----------------------------------------------------------------------------
-dnl get the name of the LiveSupport database
+dnl get the name of the Campcaster database
dnl-----------------------------------------------------------------------------
AC_SUBST(DATABASE)
AC_ARG_WITH([database],
AC_HELP_STRING([--with-database],
- [the name of the postgresql database to use (LiveSupport)]),
- [DATABASE=${withval}], [DATABASE=LiveSupport])
+ [the name of the postgresql database to use (Campcaster)]),
+ [DATABASE=${withval}], [DATABASE=Campcaster])
AC_MSG_RESULT([using database: ${DATABASE}])
@@ -206,8 +206,8 @@ AC_SUBST(DB_USER)
AC_ARG_WITH([database-user],
AC_HELP_STRING([--with-database-user],
- [use the specified database server user (livesupport)]),
- [DB_USER=${withval}], [DB_USER=livesupport])
+ [use the specified database server user (campcaster)]),
+ [DB_USER=${withval}], [DB_USER=campcaster])
AC_MSG_RESULT([using database server user: ${DB_USER}])
@@ -219,8 +219,8 @@ AC_SUBST(DB_PASSWORD)
AC_ARG_WITH([database-password],
AC_HELP_STRING([--with-database-password],
- [use the specified database server user password (livesupport)]),
- [DB_PASSWORD=${withval}], [DB_PASSWORD=livesupport])
+ [use the specified database server user password (campcaster)]),
+ [DB_PASSWORD=${withval}], [DB_PASSWORD=campcaster])
AC_MSG_RESULT([using database server user password: ${DB_PASSWORD}])
diff --git a/livesupport/src/products/gLiveSupport/etc/doxygen.config b/livesupport/src/products/gLiveSupport/etc/doxygen.config
index 635c7f44f..bebe33162 100644
--- a/livesupport/src/products/gLiveSupport/etc/doxygen.config
+++ b/livesupport/src/products/gLiveSupport/etc/doxygen.config
@@ -44,7 +44,7 @@
# The PROJECT_NAME tag is a single word (or a sequence of words surrounded
# by quotes) that should identify the project.
-PROJECT_NAME = LiveSupport
+PROJECT_NAME = Campcaster
# The PROJECT_NUMBER tag can be used to enter a project or revision number.
# This could be handy for archiving the generated documentation or
diff --git a/livesupport/src/products/gLiveSupport/etc/storageClient.xml b/livesupport/src/products/gLiveSupport/etc/storageClient.xml
index 93dda22df..46534a9e4 100644
--- a/livesupport/src/products/gLiveSupport/etc/storageClient.xml
+++ b/livesupport/src/products/gLiveSupport/etc/storageClient.xml
@@ -15,6 +15,6 @@
+ path="/campcasterStorageServer/xmlrpc/xrLocStor.php" />
diff --git a/livesupport/src/products/gLiveSupport/etc/testResultToHtml.xsl b/livesupport/src/products/gLiveSupport/etc/testResultToHtml.xsl
index d2165c2a4..b70f32d45 100644
--- a/livesupport/src/products/gLiveSupport/etc/testResultToHtml.xsl
+++ b/livesupport/src/products/gLiveSupport/etc/testResultToHtml.xsl
@@ -5,12 +5,12 @@
- LiveSupport unit test results
+ Campcaster unit test results
Preface
This document is part of the
-LiveSupport
+Campcaster
project, Copyright © 2004 Media
Development Loan Fund, under the GNU
GPL.
@@ -18,7 +18,7 @@ Development Loan Fund, under the GNU
This is an automatically generated document.
Scope
This document contains the generated unit test results for the
-LiveSupport project.
+Campcaster project.
Summary
diff --git a/livesupport/src/products/gLiveSupport/src/GLiveSupportTest.cxx b/livesupport/src/products/gLiveSupport/src/GLiveSupportTest.cxx
index 9849fdf33..1da5c6edb 100644
--- a/livesupport/src/products/gLiveSupport/src/GLiveSupportTest.cxx
+++ b/livesupport/src/products/gLiveSupport/src/GLiveSupportTest.cxx
@@ -79,14 +79,14 @@ namespace {
* The name of the generic configuration file for the GLiveSupport object.
*/
const std::string gLiveSupportEtcConfigFileName
- = "etc/gLiveSupport.xml";
+ = "etc/campcaster-studio.xml";
/**
* The name of the user-specific configuration file for the
* GLiveSupport object, relative to the user's home directory.
*/
const std::string gLiveSupportUserConfigFileName
- = "/.livesupport/gLiveSupport.xml";
+ = "/.campcaster/campcaster-studio.xml";
/**
* The login name.
diff --git a/livesupport/src/products/scheduler/bin/run_tests.sh b/livesupport/src/products/scheduler/bin/run_tests.sh
index ee02a7546..eef4562ad 100755
--- a/livesupport/src/products/scheduler/bin/run_tests.sh
+++ b/livesupport/src/products/scheduler/bin/run_tests.sh
@@ -54,8 +54,8 @@ else
echo "Can't find testRunner executable.";
fi
-if [ -f ~/.livesupport/scheduler.xml ]; then
- config_file=~/.livesupport/scheduler.xml
+if [ -f ~/.campcaster/scheduler.xml ]; then
+ config_file=~/.campcaster/scheduler.xml
elif [ -f $etcdir/scheduler.xml ]; then
config_file=$etcdir/scheduler.xml
else
diff --git a/livesupport/src/products/scheduler/etc/Makefile.in b/livesupport/src/products/scheduler/etc/Makefile.in
index 372abc2d5..ee4c23836 100644
--- a/livesupport/src/products/scheduler/etc/Makefile.in
+++ b/livesupport/src/products/scheduler/etc/Makefile.in
@@ -75,7 +75,7 @@ DB_USER = @DB_USER@
DB_PASSWORD = @DB_PASSWORD@
AUDIO_OUT = "@AUDIO_OUT@"
-PHP_URL_PREFIX=livesupport
+PHP_URL_PREFIX=campcaster
ALIB_XML_RPC_PREFIX=xmlrpc/xrLocStor.php
POSTGRES_USER=postgres
diff --git a/livesupport/src/products/scheduler/etc/configure.ac b/livesupport/src/products/scheduler/etc/configure.ac
index f6700750d..0f219f6c6 100644
--- a/livesupport/src/products/scheduler/etc/configure.ac
+++ b/livesupport/src/products/scheduler/etc/configure.ac
@@ -135,18 +135,18 @@ fi
dnl-----------------------------------------------------------------------------
-dnl specify wether the LiveSupport database and user should be created
+dnl specify wether the Campcaster database and user should be created
dnl-----------------------------------------------------------------------------
AC_SUBST(CREATE_LS_DATABASE)
AC_ARG_WITH([create-database],
AC_HELP_STRING([--with-create-database],
- [specify wether the LiveSupport database and database user
+ [specify wether the Campcaster database and database user
should be created (no)]),
[CREATE_LS_DATABASE=${withval}],
[CREATE_LS_DATABASE=no])
-AC_MSG_RESULT([creating LiveSupport database: ${CREATE_LS_DATABASE}])
+AC_MSG_RESULT([creating Campcaster database: ${CREATE_LS_DATABASE}])
dnl-----------------------------------------------------------------------------
@@ -156,7 +156,7 @@ AC_SUBST(CREATE_ODBC_DATA_SOURCE)
AC_ARG_WITH([create-odbc-data-source],
AC_HELP_STRING([--with-create-odbc-data-source],
- [specify wether the ODBC data source for LiveSupport should be
+ [specify wether the ODBC data source for Campcaster should be
created (no)]),
[CREATE_ODBC_DATA_SOURCE=${withval}],
[CREATE_ODBC_DATA_SOURCE=no])
@@ -165,18 +165,18 @@ AC_MSG_RESULT([creating ODBC data source: ${CREATE_ODBC_DATA_SOURCE}])
dnl-----------------------------------------------------------------------------
-dnl specify wether the LiveSupport database tables should be initialized
+dnl specify wether the Campcaster database tables should be initialized
dnl-----------------------------------------------------------------------------
AC_SUBST(INIT_LS_DATABASE)
AC_ARG_WITH([init-database],
AC_HELP_STRING([--with-init-database],
- [specify wether the LiveSupport database tables should be
+ [specify wether the Campcaster database tables should be
initialized (no)]),
[INIT_LS_DATABASE=${withval}],
[INIT_LS_DATABASE=no])
-AC_MSG_RESULT([initializing LiveSupport database: ${INIT_LS_DATABASE}])
+AC_MSG_RESULT([initializing Campcaster database: ${INIT_LS_DATABASE}])
dnl-----------------------------------------------------------------------------
@@ -232,14 +232,14 @@ AC_MSG_RESULT([using database server: ${DB_SERVER}])
dnl-----------------------------------------------------------------------------
-dnl get the name of the LiveSupport database
+dnl get the name of the Campcaster database
dnl-----------------------------------------------------------------------------
AC_SUBST(DATABASE)
AC_ARG_WITH([database],
AC_HELP_STRING([--with-database],
- [the name of the postgresql database to use (LiveSupport)]),
- [DATABASE=${withval}], [DATABASE=LiveSupport])
+ [the name of the postgresql database to use (Campcaster)]),
+ [DATABASE=${withval}], [DATABASE=Campcaster])
AC_MSG_RESULT([using database: ${DATABASE}])
@@ -251,8 +251,8 @@ AC_SUBST(DB_USER)
AC_ARG_WITH([database-user],
AC_HELP_STRING([--with-database-user],
- [use the specified database server user (livesupport)]),
- [DB_USER=${withval}], [DB_USER=livesupport])
+ [use the specified database server user (campcaster)]),
+ [DB_USER=${withval}], [DB_USER=campcaster])
AC_MSG_RESULT([using database server user: ${DB_USER}])
@@ -264,8 +264,8 @@ AC_SUBST(DB_PASSWORD)
AC_ARG_WITH([database-password],
AC_HELP_STRING([--with-database-password],
- [use the specified database server user password (livesupport)]),
- [DB_PASSWORD=${withval}], [DB_PASSWORD=livesupport])
+ [use the specified database server user password (campcaster)]),
+ [DB_PASSWORD=${withval}], [DB_PASSWORD=campcaster])
AC_MSG_RESULT([using database server user password: ${DB_PASSWORD}])
@@ -297,9 +297,9 @@ AC_MSG_NOTICE(
database user: ${DB_USER}
database user password: ${DB_PASSWORD}
audio output device: ${AUDIO_OUT}
- creating LiveSupport database: ${CREATE_LS_DATABASE}
+ creating Campcaster database: ${CREATE_LS_DATABASE}
creating ODBC data source: ${CREATE_ODBC_DATA_SOURCE}
- initialize LiveSupport database: ${INIT_LS_DATABASE}
+ initialize Campcaster database: ${INIT_LS_DATABASE}
])
diff --git a/livesupport/src/products/scheduler/etc/connectionManagerFactory.xml b/livesupport/src/products/scheduler/etc/connectionManagerFactory.xml
index 0eb143638..9e7c74905 100644
--- a/livesupport/src/products/scheduler/etc/connectionManagerFactory.xml
+++ b/livesupport/src/products/scheduler/etc/connectionManagerFactory.xml
@@ -9,7 +9,7 @@
]>
-
diff --git a/livesupport/src/products/scheduler/etc/doxygen.config b/livesupport/src/products/scheduler/etc/doxygen.config
index 635c7f44f..bebe33162 100644
--- a/livesupport/src/products/scheduler/etc/doxygen.config
+++ b/livesupport/src/products/scheduler/etc/doxygen.config
@@ -44,7 +44,7 @@
# The PROJECT_NAME tag is a single word (or a sequence of words surrounded
# by quotes) that should identify the project.
-PROJECT_NAME = LiveSupport
+PROJECT_NAME = Campcaster
# The PROJECT_NUMBER tag can be used to enter a project or revision number.
# This could be handy for archiving the generated documentation or
diff --git a/livesupport/src/products/scheduler/etc/scheduler-local.xml b/livesupport/src/products/scheduler/etc/scheduler-local.xml
index cb5051b3b..b1761fe5f 100644
--- a/livesupport/src/products/scheduler/etc/scheduler-local.xml
+++ b/livesupport/src/products/scheduler/etc/scheduler-local.xml
@@ -83,7 +83,7 @@
-
diff --git a/livesupport/src/products/scheduler/etc/scheduler.xml b/livesupport/src/products/scheduler/etc/scheduler.xml
index 357aafd6b..8c0cc43f0 100644
--- a/livesupport/src/products/scheduler/etc/scheduler.xml
+++ b/livesupport/src/products/scheduler/etc/scheduler.xml
@@ -86,7 +86,7 @@
-
@@ -95,14 +95,14 @@
+ path="/campcasterStorageServer/xmlrpc/xrLocStor.php" />
+ path="/campcasterStorageServer/xmlrpc/xrLocStor.php" />
diff --git a/livesupport/src/products/scheduler/etc/testResultToHtml.xsl b/livesupport/src/products/scheduler/etc/testResultToHtml.xsl
index d2165c2a4..b70f32d45 100644
--- a/livesupport/src/products/scheduler/etc/testResultToHtml.xsl
+++ b/livesupport/src/products/scheduler/etc/testResultToHtml.xsl
@@ -5,12 +5,12 @@
- LiveSupport unit test results
+ Campcaster unit test results
Preface
This document is part of the
-LiveSupport
+Campcaster
project, Copyright © 2004 Media
Development Loan Fund, under the GNU
GPL.
@@ -18,7 +18,7 @@ Development Loan Fund, under the GNU
This is an automatically generated document.
Scope
This document contains the generated unit test results for the
-LiveSupport project.
+Campcaster project.
Summary
diff --git a/livesupport/src/products/scheduler/etc/webAuthenticationClient.xml b/livesupport/src/products/scheduler/etc/webAuthenticationClient.xml
index f13840213..a63a04718 100644
--- a/livesupport/src/products/scheduler/etc/webAuthenticationClient.xml
+++ b/livesupport/src/products/scheduler/etc/webAuthenticationClient.xml
@@ -14,6 +14,6 @@
+ path="/campcasterStorageServer/xmlrpc/xrLocStor.php" />
diff --git a/livesupport/src/products/scheduler/etc/webStorageClient.xml b/livesupport/src/products/scheduler/etc/webStorageClient.xml
index 557ce5a2a..2b9440524 100644
--- a/livesupport/src/products/scheduler/etc/webStorageClient.xml
+++ b/livesupport/src/products/scheduler/etc/webStorageClient.xml
@@ -15,6 +15,6 @@
+ path="/campcasterStorageServer/xmlrpc/xrLocStor.php" />
diff --git a/livesupport/src/modules/core/src/BaseTestMethod.cxx b/livesupport/src/modules/core/src/BaseTestMethod.cxx
index c940c328b..ed56d1acd 100644
--- a/livesupport/src/modules/core/src/BaseTestMethod.cxx
+++ b/livesupport/src/modules/core/src/BaseTestMethod.cxx
@@ -106,11 +106,11 @@ BaseTestMethod :: getConfigFile(const std::string configFileName)
std::string fileName;
std::ifstream file;
// first, try with ~/.livesupport/configFileName
struct passwd * pwd = getpwuid(getuid());
if (pwd) {
fileName += pwd->pw_dir;
- fileName += "/.livesupport/" + configFileName;
+ fileName += "/.campcaster/" + configFileName;
file.open(fileName.c_str());
if (file.good()) {
file.close();
@@ -106,11 +106,11 @@ BaseTestMethod :: getConfigFile(const std::string configFileName)
std::string fileName;
std::ifstream file;
- // first, try with ~/.livesupport/configFileName
+ // first, try with ~/.campcaster/configFileName
struct passwd * pwd = getpwuid(getuid());
if (pwd) {
diff --git a/livesupport/src/modules/htmlUI/var/ui_handler.class.php b/livesupport/src/modules/htmlUI/var/ui_handler.class.php
index 44c8a54d9..ea88748a3 100644
--- a/livesupport/src/modules/htmlUI/var/ui_handler.class.php
+++ b/livesupport/src/modules/htmlUI/var/ui_handler.class.php
@@ -5,7 +5,7 @@ define('ACTION_BASE', '/actions' ) ;
/**
* uiHandler class
*
* LiveSupport HTML User Interface module
*/
class uiHandler extends uiBase {
# var $redirUrl;
@@ -131,7 +131,7 @@ class uiHandler extends uiBase {
return FALSE;
}
- $tmpgunid = md5(microtime().$_SERVER['SERVER_ADDR'].rand()."org.mdlf.livesupport");
+ $tmpgunid = md5(microtime().$_SERVER['SERVER_ADDR'].rand()."org.mdlf.campcaster");
$ntmp = $this->gb->bufferDir.'/'.$tmpgunid;
move_uploaded_file($formdata['mediafile']['tmp_name'], $ntmp);
chmod($ntmp, 0664);
@@ -586,4 +586,4 @@ class uiHandler extends uiBase {
} // fn changeStationPrefs
} // class uiHandler
-?>
\ No newline at end of file
+?>
@@ -5,7 +5,7 @@ define('ACTION_BASE', '/actions' ) ;
* uiHandler class
*
- * LiveSupport HTML User Interface module
+ * Campcaster HTML User Interface module
*/
class uiHandler extends uiBase {
diff --git a/livesupport/src/products/scheduler/bin/scheduler_devenv.sh b/livesupport/src/products/scheduler/bin/scheduler_devenv.sh
index d8809696c..9d5168497 100755
--- a/livesupport/src/products/scheduler/bin/scheduler_devenv.sh
+++ b/livesupport/src/products/scheduler/bin/scheduler_devenv.sh
@@ -26,8 +26,8 @@
#-------------------------------------------------------------------------------
#-------------------------------------------------------------------------------
# System V runlevel style invoke script for the LiveSupport Scheduler
# This script is only used in the LiveSupport development environment
#-------------------------------------------------------------------------------
@@ -57,8 +57,8 @@ else
echo "Can't find scheduler executable.";
fi
-if [ -f ~/.livesupport/scheduler.xml ]; then
- config_file=~/.livesupport/scheduler.xml
+if [ -f ~/.campcaster/scheduler.xml ]; then
+ config_file=~/.campcaster/scheduler.xml
elif [ -f $etcdir/scheduler.xml ]; then
config_file=$etcdir/scheduler.xml
else
@@ -76,56 +76,56 @@ mode=$1
#-------------------------------------------------------------------------------
case "$mode" in
'start')
- echo "Starting the LiveSupport scheduler..."
+ echo "Starting the Campcaster scheduler..."
$scheduler_exe -c $config_file start
sleep 2
;;
'run')
- echo "Running the LiveSupport scheduler..."
+ echo "Running the Campcaster scheduler..."
$scheduler_exe -c $config_file --debug start
sleep 2
;;
'stop')
- echo "Stopping the LiveSupport scheduler..."
+ echo "Stopping the Campcaster scheduler..."
$scheduler_exe -c $config_file stop
sleep 2
;;
'restart')
- echo "Stopping the LiveSupport scheduler..."
+ echo "Stopping the Campcaster scheduler..."
$scheduler_exe -c $config_file stop
sleep 2
- echo "Starting the LiveSupport scheduler..."
+ echo "Starting the Campcaster scheduler..."
$scheduler_exe -c $config_file start
sleep 2
;;
'status')
- echo "Checking LiveSupport scheduler status..."
+ echo "Checking Campcaster scheduler status..."
$scheduler_exe -c $config_file status
;;
'install')
- echo "Installing LiveSupport scheduler database tables..."
+ echo "Installing Campcaster scheduler database tables..."
$scheduler_exe -c $config_file install
;;
'uninstall')
- echo "Uninstalling LiveSupport scheduler database tables..."
+ echo "Uninstalling Campcaster scheduler database tables..."
$scheduler_exe -c $config_file uninstall
;;
'kill')
- echo "Killing all LiveSupport scheduler processes..."
+ echo "Killing all Campcaster scheduler processes..."
killall scheduler
sleep 2
killall -9 scheduler
;;
*)
- echo "LiveSupport scheduler System V runlevel init script."
+ echo "Campcaster scheduler System V runlevel init script."
echo ""
echo "Usage:"
echo " $0 start|run|stop|restart|status|install|uninstall|kill"
@@ -26,8 +26,8 @@
#-------------------------------------------------------------------------------
#-------------------------------------------------------------------------------
-# System V runlevel style invoke script for the LiveSupport Scheduler
-# This script is only used in the LiveSupport development environment
+# System V runlevel style invoke script for the Campcaster Scheduler
+# This script is only used in the Campcaster development environment
#-------------------------------------------------------------------------------